@@ -306,6 +306,7 @@ class TriggerFunction(
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
         events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
@@ -352,6 +353,7 @@ class TriggerFunction(
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
+        :param ephemeral_storage_size: The size of the function’s /tmp directory in MiB. Default: 512 MiB
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -396,6 +398,7 @@ class TriggerFunction(
             description=description,
             environment=environment,
             environment_encryption=environment_encryption,
+            ephemeral_storage_size=ephemeral_storage_size,
             events=events,
             filesystem=filesystem,
             function_name=function_name,
@@ -698,6 +701,7 @@ class TriggerProps(TriggerOptions):
         "description": "description",
         "environment": "environment",
         "environment_encryption": "environmentEncryption",
+        "ephemeral_storage_size": "ephemeralStorageSize",
         "events": "events",
         "filesystem": "filesystem",
         "function_name": "functionName",
@@ -746,6 +750,7 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
         events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
@@ -791,6 +796,7 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
+        :param ephemeral_storage_size: The size of the function’s /tmp directory in MiB. Default: 512 MiB
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -877,6 +883,8 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
             self._values["environment"] = environment
         if environment_encryption is not None:
             self._values["environment_encryption"] = environment_encryption
+        if ephemeral_storage_size is not None:
+            self._values["ephemeral_storage_size"] = ephemeral_storage_size
         if events is not None:
             self._values["events"] = events
         if filesystem is not None:
@@ -1105,6 +1113,15 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
         result = self._values.get("environment_encryption")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], result)
 
+    @builtins.property
+    def ephemeral_storage_size(self) -> typing.Optional[aws_cdk.core.Size]:
+        '''The size of the function’s /tmp directory in MiB.
+
+        :default: 512 MiB
+        '''
+        result = self._values.get("ephemeral_storage_size")
+        return typing.cast(typing.Optional[aws_cdk.core.Size], result)
+
     @builtins.property
     def events(self) -> typing.Optional[typing.List[aws_cdk.aws_lambda.IEventSource]]:
         '''Event sources for this function.
